@@ -8,6 +8,7 @@ from tensorflow.keras.preprocessing.text import Tokenizer
 from tensorflow.keras.utils import to_categorical
 import tensorflow as tf
 from deepac.utils import set_mem_growth
+from tensorflow.keras.utils import get_custom_objects
 
 from Bio import SeqIO
 
@@ -23,9 +24,14 @@ def get_filter_contribs(args, allow_eager=False):
         print("Using SHAP. Disabling eager execution...")
         tf.compat.v1.disable_v2_behavior()
     set_mem_growth()
-    model = load_model(args.model)
+    model = load_model(args.model, custom_objects=get_custom_objects())
     max_only = args.partial or args.easy_partial or not args.all_occurrences
     check_additivity = not args.no_check
+
+    target = args.target_class
+    if target is None:
+        target = 0
+
     if args.w_norm and not args.do_lstm:
         print("Create model with mean-centered weight matrices ...")
         conv_layer_idx = [idx for idx, layer in enumerate(model.layers) if "Conv1D" in str(layer)][0]
@@ -144,7 +150,7 @@ def get_filter_contribs(args, allow_eager=False):
 
         scores_filter = explainer.shap_values([intermediate_fwd,
                                                intermediate_rc], check_additivity=check_additivity)
-        scores_fwd, scores_rc = scores_filter[0]
+        scores_fwd, scores_rc = scores_filter[target]
 
         # shape: [num_reads, len_reads, n_filters]
 
