@@ -32,6 +32,8 @@ def add_gwpa_parser(gparser):
                                   help="Directory containing the predictions (.npy) of the fragmented genomes")
     parser_genomemap.add_argument("-g", "--genomes-dir", required=True, help="Directory containing genomes (.genome)")
     parser_genomemap.add_argument("-o", "--out-dir", default=".", help="Output directory")
+    parser_genomemap.add_argument("-T", "--target-class", dest="target_class", type=int,
+                                  help="Target class ID. Leave unset for binary classification")
     parser_genomemap.set_defaults(func=run_genomemap)
 
     parser_granking = gwpa_subparsers.add_parser('granking', help='Generate gene rankings.')
@@ -67,6 +69,8 @@ def add_gwpa_parser(gparser):
                                    help="Use Integrated Gradients instead of DeepLIFT.")
     parser_ntcontribs.add_argument("--no-check", dest="no_check", action="store_true",
                                    help="Disable additivity check.")
+    parser_ntcontribs.add_argument("-T", "--target-class", dest="target_class", type=int,
+                                   help="Target class ID. Leave unset for binary classification")
     parser_ntcontribs.set_defaults(func=run_ntcontribs)
 
     parser_factiv = gwpa_subparsers.add_parser('factiv', help='Get filter activations.')
@@ -147,7 +151,7 @@ def run_gff2genome(args):
 
 def gff2genome(gff3_path, out_path):
     """Generate a .genome file."""
-    ptrn = re.compile(r'\sregion')
+    ptrn = re.compile(r'(Genbank|RefSeq)\s+region')
     out_lines = []
     with open(gff3_path) as in_file:
         for line in in_file:
